@@ -5,7 +5,6 @@ import struct
 import time
 from glob import glob
 
-
 # The code in this file is partially borrowed and modified from the source
 # https://github.com/boppreh/keyboard/blob/master/keyboard/_nixcommon.py
 
@@ -110,10 +109,10 @@ device = aggregate_devices()
 
 def sequence(codes, delay):
     for code in codes:
-        device.write_event(code[3], 1)
+        device.write_event(code, 1)
         time.sleep(delay)
     codes.reverse()
     for code in codes:
-        device.write_event(code[3], 0)
+        device.write_event(code, 0)
         time.sleep(delay)
     return
