@@ -5,7 +5,7 @@ user32 = ctypes.WinDLL("user32", use_last_error=True)
 
 
 def action(code, mod):
-    [sc, vk] = code[:2]
+    [sc, vk] = code
     if sc > 128:
         sc = sc - 128
         mod += 1
